/***************************************************************************
 *                                                                         *
 *                         Powersave Daemon                                *
 *                                                                         *
 *          Copyright (C) 2004,2005 SUSE Linux Products GmbH               *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify it *
 * under the terms of the GNU General Public License as published by the   *
 * Free Software Foundation; either version 2 of the License, or (at you   *
 * option) any later version.                                              *
 *                                                                         *
 * This program is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
 * General Public License for more details.                                *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA                  *
 *                                                                         *
 ***************************************************************************/

#include "event_management.h"
#include "event.h"

#include <string>

EventManagement::EventManagement()
{
	id_count = 0;
}

int EventManagement::registerEvent(Event & event, time_t timeout)
{
	pDebug(DBG_INFO, "registering event no.'%d'", id_count);
	// give the event an unique id
	event.setID(id_count);
	// the next event will get a higher id
	id_count++;
	// set the timeout in milliseconds
	event.setTimeout(timeout * 1000);
	// start the counter which looks if an event timed out
	event.start();

	// append the event to the list of pending events
	Events.push_back(event);

	return event.ID();
}

bool EventManagement::remove(int id)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		if (id == it->ID()) {
			Events.erase(it);
			return 1;
		}
	}

	return 0;
}

int EventManagement::count()
{
	return Events.size();
}

const string EventManagement::name(int id)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		if (id == it->ID()) {
			return it->name();
		}
	}

	return "";
}

const string EventManagement::cur_prog(int id)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {
		if (id == it->ID()) {
			if (it->_current_program_2_execute != it->end()) {
				return *(it->_current_program_2_execute);
			} else {
				return "";
			}
		}
	}

	return "";
}

int EventManagement::moveOn(int id)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		if (id == it->ID()) {
			it->_current_program_2_execute++;
			if (it->_current_program_2_execute == it->end())
				return 0;

			return 1;
		}
	}

	return -1;
}

Event* EventManagement::event(int id)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		if (id == it->ID()) {
			return &(*it);
		}
	}

	return NULL;
}

void EventManagement::adjustTimeouts(unsigned long sleep_time)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		it->increaseSleeptime(sleep_time);
	}
}

int EventManagement::eventIsRunning(const std::string eventName)
{
	for (std::list < Event >::iterator it = Events.begin();
	     it != Events.end(); ++it) {

		if (eventName == it->name()) {
			return 1;
		}
	}

	return 0;
}
