/***************************************************************************
 *                                                                         *
 *                         Powersave Daemon                                *
 *                                                                         *
 *            Copyright (C) 2005 SUSE Linux Products GmbH                  *
 *                                                                         *
 * This program is free software; you can redistribute it and/or modify it *
 * under the terms of the GNU General Public License as published by the   *
 * Free Software Foundation; either version 2 of the License, or (at you   *
 * option) any later version.                                              *
 *                                                                         *
 * This program is distributed in the hope that it will be useful, but     *
 * WITHOUT ANY WARRANTY; without even the implied warranty of              *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU       *
 * General Public License for more details.                                *
 *                                                                         *
 * You should have received a copy of the GNU General Public License along *
 * with this program; if not, write to the Free Software Foundation, Inc., *
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA                  *
 *                                                                         *
 ***************************************************************************/

#include "config.h"

#ifdef HAVE_LIBHAL

#ifndef POWERSAVE_HAL_H
#define POWERSAVE_HAL_H

#define DBUS_API_SUBJECT_TO_CHANGE 1
#include <hal/libhal.h>

#include "powerlib_local.h"

/** brief get integer property through hal
 *
 * fetches one interger value through hal. Throws a dbus error with error
 * message if needed.
 *
 * @param device the device from which should be fetched
 * @param property the property which should be fetched
 *
 * @return -1 on error
 */
int hal_get_property_int(char *device, char *property);

/** brief get bool property through hal
 *
 * fetches one bool value through hal. Throws a dbus error with error
 * message if needed.
 *
 * @param device the device from which should be fetched
 * @param property the property which should be fetched
 *
 * @return -1 on error
 */
int hal_get_property_bool(char *device, char *property);

/** brief get string property through hal
 *
 * fetches one string value through hal. Throws a dbus error with error
 * message if needed.
 *
 * @param device the device from which should be fetched
 * @param property the property which should be fetched
 * @param value a char pointer in which the fetched value is stored. 
 *        value must have enough memory.
 *
 * @return -1 on error
 */
int hal_get_property_string(char *device, char *property, char *value);

/** @brief inits the access to hal 
 *
 * if hal context is already initialized, does nothing.
 *
 * @return true on success, false on failure
*/
int initHal(void);

/** @brief frees the access to hal */
void freeHal(void);

#endif				/* POWERSAVE_HAL_H */

#endif				/* HAVE_LIBHAL */
